/**
 * Created by Samuel Gratzl on 19.11.2015.
 */
// to resolve the jquery extensions
/// <reference types="bootstrap" />
import './_bootstrap';
import * as $ from 'jquery';
import { mixin } from 'phovea_core/src';
var Dialog = (function () {
    function Dialog(title, primaryBtnText) {
        if (primaryBtnText === void 0) { primaryBtnText = 'OK'; }
        this.bakKeyDownListener = null; // temporal for restoring an old keydown listener
        var dialog = document.createElement('div');
        dialog.setAttribute('role', 'dialog');
        dialog.classList.add('modal', 'fade');
        dialog.innerHTML = "\n       <div class=\"modal-dialog\" role=\"document\">\n        <div class=\"modal-content\">\n          <div class=\"modal-header\">\n            <button type=\"button\" class=\"close\" data-dismiss=\"modal\" aria-label=\"Close\"><span aria-hidden=\"true\">\u00D7</span></button>\n            <h4 class=\"modal-title\">" + title + "</h4>\n          </div>\n          <div class=\"modal-body\">\n  \n          </div>\n          <div class=\"modal-footer\">\n            <button type=\"button\" class=\"btn btn-default btn-primary\">" + primaryBtnText + "</button>\n          </div>\n        </div>\n      </div>";
        document.body.appendChild(dialog);
        this.$dialog = $(dialog);
    }
    Dialog.prototype.show = function () {
        var _this = this;
        this.bakKeyDownListener = document.onkeydown;
        document.onkeydown = function (evt) {
            evt = evt || window.event;
            if (evt.keyCode === 27) {
                _this.hide();
            }
        };
        ++Dialog.openDialogs;
        return this.$dialog.modal('show');
    };
    Dialog.prototype.hide = function () {
        document.onkeydown = this.bakKeyDownListener;
        return this.$dialog.modal('hide');
    };
    Object.defineProperty(Dialog.prototype, "body", {
        get: function () {
            return this.$dialog[0].querySelector('.modal-body');
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "footer", {
        get: function () {
            return this.$dialog.find('.modal-footer')[0];
        },
        enumerable: true,
        configurable: true
    });
    Dialog.prototype.onHide = function (callback) {
        this.$dialog.on('hidden.bs.modal', callback);
    };
    Dialog.prototype.onSubmit = function (callback) {
        return this.$dialog.find('.modal-footer > button').on('click', callback);
    };
    Dialog.prototype.hideOnSubmit = function () {
        this.onSubmit(this.hide.bind(this));
    };
    Dialog.prototype.destroy = function () {
        if (--Dialog.openDialogs > 0) {
            $('body').addClass('modal-open');
        }
        return this.$dialog.remove();
    };
    return Dialog;
}());
export { Dialog };
Dialog.openDialogs = 0;
export function generateDialog(title, primaryBtnText) {
    if (primaryBtnText === void 0) { primaryBtnText = 'OK'; }
    return new Dialog(title, primaryBtnText);
}
export function msg(text, category) {
    if (category === void 0) { category = 'info'; }
    return new Promise(function (resolve) {
        var div = $("<div class=\"alert alert-" + category + " alert-dismissible fade in\" role=\"alert\">\n        <button type=\"button\" class=\"close\" data-dismiss=\"modal\" aria-label=\"Close\"><span aria-hidden=\"true\">\u00D7</span></button>\n        " + text + "\n    </div>").appendTo('body');
        div.on('closed.bs.alert', function () { return resolve; });
        div.alert();
    });
}
/**
 * simple prompt dialog
 * @param text
 * @param options
 * @returns {Promise}
 */
export function prompt(text, options) {
    if (options === void 0) { options = {}; }
    var o = {
        title: 'Input',
        placeholder: 'Enter...',
        multiline: false
    };
    if (typeof options === 'string') {
        options = { title: options };
    }
    mixin(o, options);
    return new Promise(function (resolve) {
        var dialog = generateDialog(o.title);
        if (o.multiline) {
            dialog.body.innerHTML = "<form><textarea class=\"form-control\" rows=\"5\" placeholder=\"" + o.placeholder + "\" autofocus=\"autofocus\">" + text + "</textarea></form>";
        }
        else {
            dialog.body.innerHTML = "<form><input type=\"text\" class=\"form-control\" value=\"" + text + "\" autofocus=\"autofocus\" placeholder=\"" + o.placeholder + "\"></form>";
        }
        dialog.body.querySelector('form').onsubmit = function () {
            dialog.hide();
            return false;
        };
        dialog.onHide(function () {
            resolve(dialog.body.querySelector('input, textarea').value);
            dialog.destroy();
        });
        dialog.show();
    });
}
/**
 * simple choose dialog
 * @param items
 * @param options
 * @returns {Promise}
 */
export function choose(items, options) {
    if (options === void 0) { options = {}; }
    var o = {
        title: 'Choose',
        placeholder: 'Enter...',
        editable: false
    };
    if (typeof options === 'string') {
        options = { title: options };
    }
    mixin(o, options);
    return new Promise(function (resolve) {
        var dialog = generateDialog(o.title);
        var option = items.map(function (d) { return "<option value=\"" + d + "\">" + d + "</option>"; }).join('\n');
        if (o.editable) {
            dialog.body.innerHTML = "<form><input type=\"text\" list=\"chooseList\" class=\"form-control\" autofocus=\"autofocus\" placeholder=\"" + o.placeholder + "\">\n        <datalist id=\"chooseList\">" + option + "</datalist>\n      </form>";
        }
        else {
            dialog.body.innerHTML = "<form><select class=\"form-control\">" + option + "</select></form>";
        }
        dialog.body.querySelector('form').onsubmit = function () {
            dialog.hide();
            return false;
        };
        dialog.hideOnSubmit();
        dialog.onHide(function () {
            if (o.editable) {
                resolve(dialog.body.querySelector('input').value);
            }
            else {
                resolve(items[dialog.body.querySelector('select').selectedIndex]);
            }
            dialog.destroy();
        });
        dialog.show();
    });
}
export function areyousure(msg, options) {
    if (msg === void 0) { msg = ''; }
    if (options === void 0) { options = {}; }
    var o = {
        title: 'Are you sure?',
        button: "<i class=\"fa fa-trash\" aria-hidden=\"true\"></i> Delete"
    };
    if (typeof options === 'string') {
        options = { title: options };
    }
    mixin(o, options);
    return new Promise(function (resolve) {
        var dialog = generateDialog(o.title, 'Cancel');
        dialog.body.innerHTML = msg;
        $("<button class=\"btn btn-danger\">" + o.button + "</button>").appendTo(dialog.footer);
        var clicked = false;
        $(dialog.footer).find('button.btn-primary').on('click', function () {
            dialog.hide();
        });
        $(dialog.footer).find('button.btn-danger').on('click', function () {
            clicked = true;
            dialog.hide();
        });
        dialog.onHide(function () {
            dialog.destroy();
            resolve(clicked);
        });
        dialog.show();
    });
}
//# sourceMappingURL=dialogs.js.map