/**
 * Created by Samuel Gratzl on 24.11.2014.
 */
import * as tslib_1 from "tslib";
import './_bootstrap';
import './_font-awesome';
import './style.scss';
import * as template from 'html-loader!./_header.html';
import { getAPIJSON } from 'phovea_core/src/ajax';
import { mixin } from 'phovea_core/src/index';
import * as $ from 'jquery';
import buildBuildInfo from './buildInfo';
/**
 * Header link extends the header link with a  flag for disabling the logo
 */
var AppHeaderLink = (function () {
    function AppHeaderLink(name, action, href, addLogo) {
        if (name === void 0) { name = 'Phovea'; }
        if (action === void 0) { action = function (event) { return false; }; }
        if (href === void 0) { href = '#'; }
        if (addLogo === void 0) { addLogo = true; }
        this.name = name;
        this.action = action;
        this.href = href;
        this.addLogo = addLogo;
    }
    return AppHeaderLink;
}());
export { AppHeaderLink };
/**
 * Helper function to create a list item for the header menus
 * @param name
 * @param action
 * @param href
 * @returns {HTMLElement}
 */
function createLi(name, action, href) {
    if (href === void 0) { href = '#'; }
    var li = document.createElement('li');
    li.innerHTML = "<a href=\"" + href + "\">" + name + "</a>";
    if (action) {
        li.querySelector('a').onclick = action;
    }
    return li;
}
/**
 * The Caleydo App Header provides an app name and customizable menus
 */
var AppHeader = (function () {
    /**
     * Constructor overrides the default options with the given options
     * @param parent
     * @param options
     */
    function AppHeader(parent, options) {
        if (options === void 0) { options = {}; }
        this.parent = parent;
        /**
         * Default options that can be overridden in the constructor
         * @private
         */
        this.options = {
            /**
             * insert as first-child or append as child node to the given parent node
             */
            prepend: true,
            /**
             * color scheme: bright (= false) or dark (= true)
             */
            inverse: false,
            /**
             * @DEPRECATED use `appLink.name` instead
             */
            //app: 'Caleydo Web',
            /**
             * @DEPRECATED use `appLink.addLogo` instead
             */
            //addLogo: true,
            /**
             * the app link with the app name
             */
            appLink: new AppHeaderLink(),
            /**
             * a list of links that should be shown in the main menu
             */
            mainMenu: [],
            /**
             * a list of links that should be shown in the right menu
             */
            rightMenu: [],
            /**
             * show/hide the options link
             */
            showOptionsLink: false,
            /**
             * show/hide the bug report link
             */
            showReportBugLink: true
        };
        mixin(this.options, options);
        this.build();
    }
    AppHeader.prototype.build = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _this = this;
            var helper, appLink, msg;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        // legacy support
                        if (this.options.app !== undefined && this.options.appLink === undefined) {
                            this.options.appLink.name = this.options.app;
                        }
                        if (this.options.addLogo !== undefined && !this.options.appLink === undefined) {
                            this.options.appLink.addLogo = this.options.addLogo;
                        }
                        helper = document.createElement('div');
                        helper.innerHTML = String(template);
                        while (helper.lastChild) {
                            this.parent.insertBefore(helper.lastChild, this.parent.firstChild);
                        }
                        // use the inverse color scheme
                        if (this.options.inverse) {
                            this.parent.querySelector('nav.navbar').classList.add('navbar-inverse');
                        }
                        appLink = this.parent.querySelector('*[data-header="appLink"]');
                        appLink.innerHTML = this.options.appLink.name;
                        appLink.onclick = this.options.appLink.action;
                        appLink.setAttribute('href', this.options.appLink.href);
                        if (this.options.appLink.addLogo) {
                            appLink.classList.add('caleydo_app');
                        }
                        this.mainMenu = this.parent.querySelector('*[data-header="mainMenu"]');
                        this.rightMenu = this.parent.querySelector('*[data-header="rightMenu"]');
                        this.aboutDialog = this.parent.querySelector('*[data-header="about"]');
                        this.optionsDialog = this.parent.querySelector('*[data-header="options"]');
                        // show/hide links
                        this.toggleOptionsLink(this.options.showOptionsLink);
                        this.toggleAboutLink(true); // always visible
                        this.toggleReportBugLink(this.options.showReportBugLink);
                        this.options.mainMenu.forEach(function (l) { return _this.addMainMenu(l.name, l.action, l.href); });
                        this.options.rightMenu.forEach(function (l) { return _this.addRightMenu(l.name, l.action, l.href); });
                        return [4 /*yield*/, Promise.resolve(getAPIJSON("/last_deployment", {}))];
                    case 1:
                        msg = _a.sent();
                        if (msg.timestamp) {
                            this.aboutDialog.querySelector('.lastDeployment span').textContent = new Date(msg.timestamp).toUTCString();
                        }
                        return [2 /*return*/];
                }
            });
        });
    };
    AppHeader.prototype.addMainMenu = function (name, action, href) {
        if (href === void 0) { href = '#'; }
        var li = createLi(name, action, href);
        this.mainMenu.appendChild(li);
        return li;
    };
    AppHeader.prototype.addRightMenu = function (name, action, href) {
        if (href === void 0) { href = '#'; }
        var li = createLi(name, action, href);
        this.rightMenu.insertBefore(li, this.rightMenu.firstChild);
        return li;
    };
    AppHeader.prototype.insertCustomMenu = function (element) {
        this.rightMenu.parentElement.insertBefore(element, this.rightMenu);
    };
    AppHeader.prototype.insertCustomRightMenu = function (element) {
        this.rightMenu.parentElement.appendChild(element);
    };
    AppHeader.prototype.wait = function () {
        AppHeader.setVisibility(document.querySelector('#headerWaitingOverlay'), true);
        //$('#headerWaitingOverlay').fadeIn();
    };
    AppHeader.prototype.ready = function () {
        AppHeader.setVisibility(document.querySelector('#headerWaitingOverlay'), false);
        //$('#headerWaitingOverlay').fadeOut();
    };
    AppHeader.setVisibility = function (element, isVisible) {
        if (isVisible) {
            element.classList.remove('hidden');
        }
        else {
            element.classList.add('hidden');
        }
    };
    AppHeader.prototype.toggleOptionsLink = function (isVisible) {
        var link = this.parent.querySelector('*[data-header="optionsLink"]');
        AppHeader.setVisibility(link, isVisible);
    };
    AppHeader.prototype.toggleReportBugLink = function (isVisible) {
        var _this = this;
        var link = this.parent.querySelector('*[data-header="bugLink"]');
        AppHeader.setVisibility(link, isVisible);
        // set the URL to GitHub issues dynamically
        if (isVisible) {
            $('#headerReportBugDialog').on('show.bs.modal', function () {
                var content = _this.parent.querySelector('*[data-header="bug"]');
                content.innerHTML = 'Loading...';
                buildBuildInfo().then(function (buildInfo) {
                    content.innerHTML = buildInfo.toHTML();
                }).catch(function (error) {
                    content.innerHTML = error.toString();
                });
            });
        }
    };
    AppHeader.prototype.toggleAboutLink = function (isVisible) {
        var _this = this;
        var link = this.parent.querySelector('*[data-header="aboutLink"]');
        AppHeader.setVisibility(link, isVisible);
        if (isVisible) {
            link.addEventListener('click', function () {
                // request last deployment data
                Promise.resolve(getAPIJSON("/last_deployment", {})).then(function (msg) {
                    if (msg.timestamp) {
                        _this.aboutDialog.querySelector('.lastDeployment span').textContent = new Date(msg.timestamp).toUTCString();
                    }
                });
            });
        }
    };
    return AppHeader;
}());
export { AppHeader };
export function create(parent, options) {
    if (options === void 0) { options = {}; }
    return new AppHeader(parent, options);
}
//# sourceMappingURL=header.js.map